<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fa">
<context>
    <name>MircastShowWidget</name>
    <message>
        <source>Projecting... 
Please do not exit the Movie app during the process.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exit Miracast</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MircastWidget</name>
    <message>
        <source>Project to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Searching for devices...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No Miracast display devices were found. Please connect the device and your computer to the same WLAN network.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Invalid folder</source>
        <translation>پوشه نامعتبر</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>باز کردن پوشه</translation>
    </message>
    <message>
        <source>Network disconnected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>شما مجوز کار با  این پوشه را ندارید</translation>
    </message>
    <message>
        <source>Auto add similar files to play</source>
        <translation>به صورت خودکار فایل های مشابه را برای اجرا اضافه کن</translation>
    </message>
    <message>
        <source>Clear playlist when exit</source>
        <translation>پاک کردن لیست پخش هنگام خروج</translation>
    </message>
    <message>
        <source>Show video preview on mouseover</source>
        <translation>نمایش پیش نمایش ویدیو با اشاره ماوس</translation>
    </message>
    <message>
        <source>Open a new player for each file played</source>
        <translation>باز کردن یک پلیر جدید برای هر فایل اجرا شده</translation>
    </message>
    <message>
        <source>Pause when minimized</source>
        <translation>توقف در هنگام کمینه</translation>
    </message>
    <message>
        <source>Remember playback position</source>
        <translation>بازیابی موقعیت پخش</translation>
    </message>
    <message>
        <source>Path</source>
        <translation>مسیر</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>پایه ای</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>پخش</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>تصویر از صفحه</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>میانبر</translation>
    </message>
    <message>
        <source>File</source>
        <translation>فایل</translation>
    </message>
    <message>
        <source>Frame/Sound</source>
        <translation>فریم/صدا</translation>
    </message>
    <message>
        <source>Playback</source>
        <translation>بازنواخت</translation>
    </message>
    <message>
        <source>Subtitle</source>
        <translation>زیرنویس</translation>
    </message>
    <message>
        <source>Font Style</source>
        <translation>سبک فونت</translation>
    </message>
    <message>
        <source>Restore Defaults</source>
        <translation>بازگرداندن پیش فرض ها</translation>
    </message>
    <message>
        <source>Open file</source>
        <translation>باز کردن فایل</translation>
    </message>
    <message>
        <source>Open next</source>
        <translation>باز کردن بعدی</translation>
    </message>
    <message>
        <source>Open previous</source>
        <translation>باز کردن قبلی</translation>
    </message>
    <message>
        <source>Mini mode</source>
        <translation>حالت کوچک</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>بی صدا</translation>
    </message>
    <message>
        <source>Next frame</source>
        <translation>فریم بعدی</translation>
    </message>
    <message>
        <source>Previous frame</source>
        <translation>فریم قبلی</translation>
    </message>
    <message>
        <source>Volume down</source>
        <translation>کاهش صدا</translation>
    </message>
    <message>
        <source>Volume up</source>
        <translation>افزایش صدا</translation>
    </message>
    <message>
        <source>Speed up</source>
        <translation>افزایش سرعت</translation>
    </message>
    <message>
        <source>Speed down</source>
        <translation>کاهش سرعت</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>تمام صفحه</translation>
    </message>
    <message>
        <source>Pause/Play</source>
        <translation>وقفه/اجرا</translation>
    </message>
    <message>
        <source>Playlist</source>
        <translation>لیست پخش</translation>
    </message>
    <message>
        <source>Reset speed</source>
        <translation>برگرداندن  سرعت</translation>
    </message>
    <message>
        <source>Rewind</source>
        <translation>به عقب</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>به جلو</translation>
    </message>
    <message>
        <source>Film screenshot</source>
        <translation>عکس گرفتن از فیلم</translation>
    </message>
    <message>
        <source>0.5s backward</source>
        <translation>0.5s رو به عقب </translation>
    </message>
    <message>
        <source>0.5s forward</source>
        <translation>0.5s رو به جلو </translation>
    </message>
    <message>
        <source>Font</source>
        <translation>فونت</translation>
    </message>
    <message>
        <source>Exit fullscreen/mini mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Movie</source>
        <translation>فیلم</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>تنظیمات</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>راهنما</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>نمایش میانبرها</translation>
    </message>
    <message>
        <source>Delete from playlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Film info</source>
        <translation>دریاره فیلم</translation>
    </message>
    <message>
        <source>Burst shooting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Size</source>
        <translation>حجم</translation>
    </message>
    <message>
        <source>Movie is a full-featured video player, supporting playing local and streaming media in multiple video formats.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show thumbnails in progress bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default play mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished">باشه</translation>
    </message>
    <message>
        <source>Decoding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto select (Recommended)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hardware decoding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Software decoding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Customize</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Decode mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The custom decoding method needs to be restarted before it can take effect,
and whether to restart it?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rendering engine</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UrlDialog</name>
    <message>
        <source>Cancel</source>
        <translation>انصراف</translation>
    </message>
    <message>
        <source>Please enter the URL:</source>
        <translation>لطفا URL را وارد نمایید</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>باشه</translation>
    </message>
</context>
<context>
    <name>dmr::ActionFactory</name>
    <message>
        <source>Settings</source>
        <translation>تنظیمات</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>تمام صفحه</translation>
    </message>
    <message>
        <source>Always on Top</source>
        <translation>همیشه رو باشد</translation>
    </message>
    <message>
        <source>Empty playlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Film info</source>
        <translation>دریاره فیلم</translation>
    </message>
    <message>
        <source>Open file</source>
        <translation>باز کردن فایل</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>باز کردن پوشه</translation>
    </message>
    <message>
        <source>Open URL</source>
        <translation>باز کردن URL </translation>
    </message>
    <message>
        <source>Open CD/DVD</source>
        <translation>باز کردن CD/DVF</translation>
    </message>
    <message>
        <source>Mini Mode</source>
        <translation>حالت کوچک</translation>
    </message>
    <message>
        <source>Play Mode</source>
        <translation>حالت پخش</translation>
    </message>
    <message>
        <source>Order Play</source>
        <translation>اجرای سفارشی</translation>
    </message>
    <message>
        <source>Shuffle Play</source>
        <translation>اجرای درهم</translation>
    </message>
    <message>
        <source>Single Play</source>
        <translation>اجرای تک</translation>
    </message>
    <message>
        <source>Single Loop</source>
        <translation>تکرار یک مورد</translation>
    </message>
    <message>
        <source>List Loop</source>
        <translation>لیست تکرار</translation>
    </message>
    <message>
        <source>Frame</source>
        <translation>فریم</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>پیش فرض</translation>
    </message>
    <message>
        <source>Clockwise</source>
        <translation>ساعت  گرد</translation>
    </message>
    <message>
        <source>Counterclockwise</source>
        <translation>پاد ساعتگرد</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>صدا</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>کانال</translation>
    </message>
    <message>
        <source>Stereo</source>
        <translation>استریو</translation>
    </message>
    <message>
        <source>Left channel</source>
        <translation>کانال چپ</translation>
    </message>
    <message>
        <source>Right channel</source>
        <translation>کانال راست</translation>
    </message>
    <message>
        <source>Track</source>
        <translation>ترک</translation>
    </message>
    <message>
        <source>Subtitle</source>
        <translation>زیرنویس</translation>
    </message>
    <message>
        <source>Load</source>
        <translation>بارگذاری</translation>
    </message>
    <message>
        <source>Online Search</source>
        <translation>جستجوی آنلاین</translation>
    </message>
    <message>
        <source>Select</source>
        <translation>انتخاب</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>مخفی</translation>
    </message>
    <message>
        <source>Encodings</source>
        <translation>رمزگذاری</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>تصویر از صفحه</translation>
    </message>
    <message>
        <source>Film Screenshot</source>
        <translation>عکس از فیلم</translation>
    </message>
    <message>
        <source>Burst Shooting</source>
        <translation>عکس متوالی</translation>
    </message>
    <message>
        <source>Playlist</source>
        <translation>لیست پخش</translation>
    </message>
    <message>
        <source>Film Info</source>
        <translation>درباره فیلم</translation>
    </message>
    <message>
        <source>Delete from playlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>نمایش درمدیریت فایل</translation>
    </message>
    <message>
        <source>Next Frame</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Previous Frame</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open screenshot folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Playback Speed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>0.5x</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1.0x</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1.2x</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1.5x</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>2.0x</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dmr::BurstScreenshotsDialog</name>
    <message>
        <source>Duration: %1</source>
        <translation>مدت زمان 1%</translation>
    </message>
    <message>
        <source>Resolution: %1</source>
        <translation>وضوح 1%</translation>
    </message>
    <message>
        <source>Size: %1</source>
        <translation>سایز 1%</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>ذخیره</translation>
    </message>
</context>
<context>
    <name>dmr::MainWindow</name>
    <message>
        <source>Load successfully</source>
        <translation>با موفقیت بازگذاری شد</translation>
    </message>
    <message>
        <source>Load failed</source>
        <translation>بارگذاری ناموفق بود</translation>
    </message>
    <message>
        <source>Buffering...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>باز کردن پوشه</translation>
    </message>
    <message>
        <source>Stereo</source>
        <translation>استریو</translation>
    </message>
    <message>
        <source>Left channel</source>
        <translation>کانال چپ</translation>
    </message>
    <message>
        <source>Right channel</source>
        <translation>کانال راست</translation>
    </message>
    <message>
        <source>Parse failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>بی صدا</translation>
    </message>
    <message>
        <source>Volume: %1%</source>
        <translation>صدا %1%</translation>
    </message>
    <message>
        <source>Track: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Subtitle %1: %2s</source>
        <translation>زیرنویس  %1:s2%</translation>
    </message>
    <message>
        <source>delayed</source>
        <translation>تعویق افتاده</translation>
    </message>
    <message>
        <source>advanced</source>
        <translation>پیشرفته</translation>
    </message>
    <message>
        <source>Speed: %1x</source>
        <translation>سرعت: x1%</translation>
    </message>
    <message>
        <source>View</source>
        <translation>نما</translation>
    </message>
    <message>
        <source>Saved to</source>
        <translation>ذخیره شده در</translation>
    </message>
    <message>
        <source>The screenshot is saved</source>
        <translation>اسکرین شات ذخیره شد</translation>
    </message>
    <message>
        <source>Failed to save the screenshot</source>
        <translation>اسکرین شات نتوانست ذخیره شود</translation>
    </message>
    <message>
        <source>Invalid file: %1</source>
        <translation>فابل نامعتبر : 1%</translation>
    </message>
    <message>
        <source>No matching online subtitles</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot open file or stream</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No video file found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Film screenshot</source>
        <translation>عکس گرفتن از فیلم</translation>
    </message>
    <message>
        <source>Taking the screenshots, please wait...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation>باشه</translation>
    </message>
    <message>
        <source>Please insert a CD/DVD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reading DVD files...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>4K video may be stuck</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Order play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shuffle play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Single play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Single loop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>List loop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The CD/DVD has been ejected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please load the video first</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please exit smart dock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot play the disc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to adjust the subtitle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The action is not supported in this video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All (*)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Subtitle (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</source>
        <comment>All (*)</comment>
        <translation type="unfinished">زیرنویس (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Miracast disconnected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">انصراف</translation>
    </message>
    <message>
        <source>Restart</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dmr::MovieInfo</name>
    <message>
        <source>%1G</source>
        <translation type="vanished">%1G</translation>
    </message>
    <message>
        <source>%1M</source>
        <translation type="vanished">%1M</translation>
    </message>
    <message>
        <source>%1K</source>
        <translation type="vanished">%1K</translation>
    </message>
    <message>
        <source>%1</source>
        <translation type="vanished">%1</translation>
    </message>
</context>
<context>
    <name>dmr::MovieInfoDialog</name>
    <message>
        <source>Film info</source>
        <translation>دریاره فیلم</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>وضوح تصویر</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Size</source>
        <translation>حجم</translation>
    </message>
    <message>
        <source>Path</source>
        <translation>مسیر</translation>
    </message>
    <message>
        <source>Codec info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video CodecID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video CodeRate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 kbps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>FPS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 fps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Proportion</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1</source>
        <translation type="unfinished">%1</translation>
    </message>
    <message>
        <source>Audio info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio CodecID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio CodeRate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio digit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 bits</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Channels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 channels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sampling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1hz</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 bps</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dmr::MpvProxy</name>
    <message>
        <source>Internal</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dmr::Platform_MainWindow</name>
    <message>
        <source>Load successfully</source>
        <translation type="unfinished">با موفقیت بازگذاری شد</translation>
    </message>
    <message>
        <source>Load failed</source>
        <translation type="unfinished">بارگذاری ناموفق بود</translation>
    </message>
    <message>
        <source>Cannot play the disc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Parse failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation type="unfinished">باز کردن پوشه</translation>
    </message>
    <message>
        <source>All (*)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Speed: %1x</source>
        <translation type="unfinished">سرعت: x1%</translation>
    </message>
    <message>
        <source>Stereo</source>
        <translation type="unfinished">استریو</translation>
    </message>
    <message>
        <source>Left channel</source>
        <translation type="unfinished">کانال چپ</translation>
    </message>
    <message>
        <source>Right channel</source>
        <translation type="unfinished">کانال راست</translation>
    </message>
    <message>
        <source>Track: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to adjust the subtitle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Subtitle %1: %2s</source>
        <translation type="unfinished">زیرنویس  %1:s2%</translation>
    </message>
    <message>
        <source>delayed</source>
        <translation type="unfinished">تعویق افتاده</translation>
    </message>
    <message>
        <source>advanced</source>
        <translation type="unfinished">پیشرفته</translation>
    </message>
    <message>
        <source>Subtitle (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</source>
        <comment>All (*)</comment>
        <translation type="unfinished">زیرنویس (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</translation>
    </message>
    <message>
        <source>View</source>
        <translation type="unfinished">نما</translation>
    </message>
    <message>
        <source>Film screenshot</source>
        <translation type="unfinished">عکس گرفتن از فیلم</translation>
    </message>
    <message>
        <source>Saved to</source>
        <translation type="unfinished">ذخیره شده در</translation>
    </message>
    <message>
        <source>The screenshot is saved</source>
        <translation type="unfinished">اسکرین شات ذخیره شد</translation>
    </message>
    <message>
        <source>Failed to save the screenshot</source>
        <translation type="unfinished">اسکرین شات نتوانست ذخیره شود</translation>
    </message>
    <message>
        <source>Taking the screenshots, please wait...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reading DVD files...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No matching online subtitles</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>4K video may be stuck</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished">باشه</translation>
    </message>
    <message>
        <source>Order play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shuffle play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Single play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Single loop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>List loop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Buffering...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mute</source>
        <translation type="unfinished">بی صدا</translation>
    </message>
    <message>
        <source>Volume: %1%</source>
        <translation type="unfinished">صدا %1%</translation>
    </message>
    <message>
        <source>Cannot open file or stream</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please insert a CD/DVD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No video file found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please load the video first</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please exit smart dock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The CD/DVD has been ejected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The action is not supported in this video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid file: %1</source>
        <translation type="unfinished">فابل نامعتبر : 1%</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Miracast disconnected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">انصراف</translation>
    </message>
    <message>
        <source>Restart</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dmr::Platform_PlayItemWidget</name>
    <message>
        <source>The file does not exist</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dmr::Platform_PlaylistWidget</name>
    <message>
        <source>Playlist</source>
        <translation type="unfinished">لیست پخش</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation type="unfinished">خالی</translation>
    </message>
    <message>
        <source>%1 videos</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dmr::Platform_ToolboxProxy</name>
    <message>
        <source>Play/Pause</source>
        <translation type="unfinished">پخش/مکث</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation type="unfinished">پیشین</translation>
    </message>
    <message>
        <source>Next</source>
        <translation type="unfinished">بعدی</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation type="unfinished">تمام صفحه</translation>
    </message>
    <message>
        <source>Playlist</source>
        <translation type="unfinished">لیست پخش</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation type="unfinished">خروج از تمام صفحه</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation type="unfinished">مکث</translation>
    </message>
    <message>
        <source>Play</source>
        <translation type="unfinished">پخش</translation>
    </message>
    <message>
        <source>Miracast</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dmr::PlayItemWidget</name>
    <message>
        <source>The file does not exist</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dmr::PlaylistWidget</name>
    <message>
        <source>Playlist</source>
        <translation>لیست پخش</translation>
    </message>
    <message>
        <source>%1 videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>خالی</translation>
    </message>
</context>
<context>
    <name>dmr::Settings</name>
    <message>
        <source>%1/Movie%2(%3).jpg</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Order play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shuffle play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Single play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Single loop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>List loop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dmr::ToolboxProxy</name>
    <message>
        <source>Play</source>
        <translation>پخش</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>پیشین</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>بعدی</translation>
    </message>
    <message>
        <source>Playlist</source>
        <translation>لیست پخش</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>تمام صفحه</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>پخش/مکث</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>خروج از تمام صفحه</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>مکث</translation>
    </message>
    <message>
        <source>Miracast</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Volume</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dmr::VolumeButton</name>
    <message>
        <source>Volume</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
